@@ -2,7 +2,7 @@
 #[cfg(feature = "codec")]
 use parity_scale_codec::{Decode, Encode};
 
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 #[cfg_attr(feature = "codec", derive(Encode, Decode))]
 pub enum StorageType {
 	Plain(String),
@@ -21,7 +21,7 @@ pub enum StorageType {
 	},
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 #[cfg_attr(feature = "codec", derive(Encode, Decode))]
 pub enum StorageHasher {
 	Blake2_128,
@@ -79,13 +79,7 @@ pub fn storage_map_key(
 
 	storage_map_key
 }
-#[test]
-fn t() {
-	println!(
-		"{}",
-		array_bytes::bytes2hex("", StorageHasher::Identity.hash(0_u64.to_ne_bytes()))
-	);
-}
+
 pub fn hex_storage_map_key_with_prefix(
 	hex_prefix: impl AsRef<str>,
 	prefix: impl AsRef<[u8]>,
